<?php
$this->load->library('ciext/ciext')->load_jquery();
$this->js_css->parse_js('newsletter/js/main.js');
?>
<?= form_open('/ajax/newsletter/newsletter_site/add', array('id' => 'newsletter', 'class' => 'newsletter_col')) ?>
<?= $hash ?>
<h4>Newsletters</h4>
<p>Stay up to date with <br />the Business City news</p>
<div class="success_message" id="message" style="display:none">Thank you for subscribing.</div>
<input type="email" maxlength="40" name="email" placeholder="email address" required="required"/>
<button type="submit" class="btn">Send</button>
<?= form_close() ?>